var ivstaudioprocessor_8h =
[
    [ "ProcessSetup", "structSteinberg_1_1Vst_1_1ProcessSetup.html", "structSteinberg_1_1Vst_1_1ProcessSetup" ],
    [ "AudioBusBuffers", "structSteinberg_1_1Vst_1_1AudioBusBuffers.html", "structSteinberg_1_1Vst_1_1AudioBusBuffers" ],
    [ "ProcessData", "structSteinberg_1_1Vst_1_1ProcessData.html", "structSteinberg_1_1Vst_1_1ProcessData" ],
    [ "IAudioProcessor", "classSteinberg_1_1Vst_1_1IAudioProcessor.html", "classSteinberg_1_1Vst_1_1IAudioProcessor" ],
    [ "IAudioPresentationLatency", "classSteinberg_1_1Vst_1_1IAudioPresentationLatency.html", "classSteinberg_1_1Vst_1_1IAudioPresentationLatency" ],
    [ "IProcessContextRequirements", "classSteinberg_1_1Vst_1_1IProcessContextRequirements.html", "classSteinberg_1_1Vst_1_1IProcessContextRequirements" ],
    [ "kVstAudioEffectClass", "ivstaudioprocessor_8h.html#ae55c95a44e931e1cd78998c94bc65ee1", null ],
    [ "ComponentFlags", "ivstaudioprocessor_8h.html#a626a070dcd2e025250f41b9c3f9817cd", [
      [ "kDistributable", "ivstaudioprocessor_8h.html#a626a070dcd2e025250f41b9c3f9817cda3185111648c1599241528f1a7f523396", null ],
      [ "kSimpleModeSupported", "ivstaudioprocessor_8h.html#a626a070dcd2e025250f41b9c3f9817cdabc2edc9bb281cebe9cc6dc00a7cac0ea", null ]
    ] ],
    [ "SymbolicSampleSizes", "ivstaudioprocessor_8h.html#addd8f2e89ed5a540c9fce2c002f35c06", [
      [ "kSample32", "ivstaudioprocessor_8h.html#addd8f2e89ed5a540c9fce2c002f35c06a199093967f5a183f86bf92bd7e61e31f", null ],
      [ "kSample64", "ivstaudioprocessor_8h.html#addd8f2e89ed5a540c9fce2c002f35c06a85edf5095f2282be74fce43030f1b900", null ]
    ] ],
    [ "ProcessModes", "ivstaudioprocessor_8h.html#ae514554bd822c5370bf9496c70302e31", [
      [ "kRealtime", "ivstaudioprocessor_8h.html#ae514554bd822c5370bf9496c70302e31af21cd390d9ad5f7929f3f0a3ab972e13", null ],
      [ "kPrefetch", "ivstaudioprocessor_8h.html#ae514554bd822c5370bf9496c70302e31a3b1caa5d658939c027cbb7759358a88a", null ],
      [ "kOffline", "ivstaudioprocessor_8h.html#ae514554bd822c5370bf9496c70302e31a27042cfd9e04c874beea670ee64ac9ab", null ]
    ] ],
    [ "kFx", "ivstaudioprocessor_8h.html#ga81395ffc74210c6b129ac5c1ad0f0450", null ],
    [ "kFxAnalyzer", "ivstaudioprocessor_8h.html#ga0017ff4ab459880956723e09c847188a", null ],
    [ "kFxBass", "ivstaudioprocessor_8h.html#ga27b925ffb4f7d3da798f2b446fe06538", null ],
    [ "kFxChannelStrip", "ivstaudioprocessor_8h.html#ga5a54a33f151d3d0068d43d377fbacaea", null ],
    [ "kFxDelay", "ivstaudioprocessor_8h.html#ga377e6c632bbed63329ad118e1d1f6780", null ],
    [ "kFxDistortion", "ivstaudioprocessor_8h.html#gad8da16bef223355cc58d3b469f876b33", null ],
    [ "kFxDrums", "ivstaudioprocessor_8h.html#ga7cc4c653b53d167ebf833dc4bcd373ba", null ],
    [ "kFxDynamics", "ivstaudioprocessor_8h.html#ga9584914ab8362461d1bb4bac52ab9fd9", null ],
    [ "kFxEQ", "ivstaudioprocessor_8h.html#ga9dbf945372efb065d5f47af0aed0c498", null ],
    [ "kFxFilter", "ivstaudioprocessor_8h.html#gaf145d8e7f4ba5cf0b6f8d1373647451f", null ],
    [ "kFxGenerator", "ivstaudioprocessor_8h.html#gafe3ff646d102a4209512d6cda3b62ac4", null ],
    [ "kFxGuitar", "ivstaudioprocessor_8h.html#ga5d7f914faef6c2a37eea292a7b16c76f", null ],
    [ "kFxInstrument", "ivstaudioprocessor_8h.html#gad632f4944a960678d6ff9b3886c878db", null ],
    [ "kFxInstrumentExternal", "ivstaudioprocessor_8h.html#ga0280f4b9390e12bf4b4846515572694a", null ],
    [ "kFxMastering", "ivstaudioprocessor_8h.html#ga6e00e778267b163458d145a6b6ac37b1", null ],
    [ "kFxMicrophone", "ivstaudioprocessor_8h.html#gada3df3cb9ee2283e1dbae231d9d18644", null ],
    [ "kFxModulation", "ivstaudioprocessor_8h.html#ga2aea8d0a0d5d5e40680ce5260f52dafd", null ],
    [ "kFxNetwork", "ivstaudioprocessor_8h.html#gab2264c85ad07f983f365ca1c53489fe3", null ],
    [ "kFxPitchShift", "ivstaudioprocessor_8h.html#ga0759e804603c37125d02cbc3b091f03b", null ],
    [ "kFxRestoration", "ivstaudioprocessor_8h.html#ga4dd95a64193b078cc91d160ae39a95ed", null ],
    [ "kFxReverb", "ivstaudioprocessor_8h.html#ga01b7fd148c1e5aefa3ea548be3257e50", null ],
    [ "kFxSpatial", "ivstaudioprocessor_8h.html#gab77fa9595f5503b0d5a49407e1a918c7", null ],
    [ "kFxSurround", "ivstaudioprocessor_8h.html#gaf9b7f8cfe416744097bfcddfdcced2e6", null ],
    [ "kFxTools", "ivstaudioprocessor_8h.html#ga658d80d06b44b28d34628e66c2f1e4e3", null ],
    [ "kFxVocals", "ivstaudioprocessor_8h.html#ga0091b72150adc715454c410d230127e9", null ],
    [ "kInstrument", "ivstaudioprocessor_8h.html#gac380562898ec7144f4e0ee3b4baa6aa3", null ],
    [ "kInstrumentDrum", "ivstaudioprocessor_8h.html#ga793ad8a6c605423f8ca78e6bfacd8e22", null ],
    [ "kInstrumentExternal", "ivstaudioprocessor_8h.html#ga2dd44f3dc1709680a63b597bac817796", null ],
    [ "kInstrumentPiano", "ivstaudioprocessor_8h.html#gadceab87ecf367542d41be60acbdf1f6a", null ],
    [ "kInstrumentSampler", "ivstaudioprocessor_8h.html#gadf71323f9881f84038a18a55f9c5693b", null ],
    [ "kInstrumentSynth", "ivstaudioprocessor_8h.html#gaadec73a763ae5856f94a1d0ad1335d58", null ],
    [ "kInstrumentSynthSampler", "ivstaudioprocessor_8h.html#gaffed7482d7d1551379ad26515f4816ef", null ],
    [ "kAmbisonics", "ivstaudioprocessor_8h.html#gae0aa5ea7deb453d05ae4a38612d30868", null ],
    [ "kAnalyzer", "ivstaudioprocessor_8h.html#gaf0d4b7073ef26a60cedee77e04e9f94f", null ],
    [ "kNoOfflineProcess", "ivstaudioprocessor_8h.html#gaa5ff5ac3ea4de85f61375ed04b2ab88a", null ],
    [ "kOnlyARA", "ivstaudioprocessor_8h.html#gab1fff222e0c2b65ce6574afa48e3b838", null ],
    [ "kOnlyOfflineProcess", "ivstaudioprocessor_8h.html#gac5a7bb9551dc86a93bc764efef832164", null ],
    [ "kOnlyRealTime", "ivstaudioprocessor_8h.html#ga5c37de66c8a6ede53f92d9ea117bbd50", null ],
    [ "kSpatial", "ivstaudioprocessor_8h.html#ga6a5beaeb94b8e0a215026ac95f44a6ab", null ],
    [ "kSpatialFx", "ivstaudioprocessor_8h.html#ga0ab3065d837d3ed2cb309b61e43e7590", null ],
    [ "kUpDownMix", "ivstaudioprocessor_8h.html#ga96b0fa2b93633f94d256d0926a23216f", null ],
    [ "kMono", "ivstaudioprocessor_8h.html#gabd5da3c6aa4168e82cf36eb2c42fac1e", null ],
    [ "kStereo", "ivstaudioprocessor_8h.html#ga74b483d71fbc43888e605cfdf8b69bd3", null ],
    [ "kSurround", "ivstaudioprocessor_8h.html#ga1cbb72f7fd4c011b07e0a249228e54ac", null ]
];